@@ -2,9 +2,9 @@
 /*! \file bool.h
  ** \verbatim
  ** Top contributors (to current version):
- **   Morgan Deters, Paul Meng
+ **   Morgan Deters, Mathias Preiner
  ** This file is part of the CVC4 project.
- ** Copyright (c) 2009-2017 by the authors listed in the file AUTHORS
+ ** Copyright (c) 2009-2020 by the authors listed in the file AUTHORS
  ** in the top-level source directory) and their institutional affiliations.
  ** All rights reserved.  See the file COPYING in the top-level source
  ** directory for licensing information.\endverbatim
@@ -16,8 +16,8 @@
 
 #include <cvc4/cvc4_public.h>
 
-#ifndef __CVC4__BOOL_H
-#define __CVC4__BOOL_H
+#ifndef CVC4__BOOL_H
+#define CVC4__BOOL_H
 
 namespace CVC4 {
 
@@ -29,4 +29,4 @@ struct BoolHashFunction {
 
 }/* CVC4 namespace */
 
-#endif /* __CVC4__BOOL_H */
+#endif /* CVC4__BOOL_H */
