@@ -2,9 +2,9 @@
 /*! \file unsafe_interrupt_exception.h
  ** \verbatim
  ** Top contributors (to current version):
- **   Liana Hadarean, Paul Meng, Tim King
+ **   Liana Hadarean, Mathias Preiner
  ** This file is part of the CVC4 project.
- ** Copyright (c) 2009-2017 by the authors listed in the file AUTHORS
+ ** Copyright (c) 2009-2020 by the authors listed in the file AUTHORS
  ** in the top-level source directory) and their institutional affiliations.
  ** All rights reserved.  See the file COPYING in the top-level source
  ** directory for licensing information.\endverbatim
@@ -15,8 +15,8 @@
 
 #include <cvc4/cvc4_public.h>
 
-#ifndef __CVC4__UNSAFE_INTERRUPT_EXCEPTION_H
-#define __CVC4__UNSAFE_INTERRUPT_EXCEPTION_H
+#ifndef CVC4__UNSAFE_INTERRUPT_EXCEPTION_H
+#define CVC4__UNSAFE_INTERRUPT_EXCEPTION_H
 
 #include <cvc4/base/exception.h>
 
@@ -40,4 +40,4 @@ public:
 
 }/* CVC4 namespace */
 
-#endif /* __CVC4__UNSAFE_INTERRUPT_EXCEPTION_H */
+#endif /* CVC4__UNSAFE_INTERRUPT_EXCEPTION_H */
